/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wamblee.inject;

/**
 * The injector factory is responsible for creating injectors for a given class.
 * This must be implemneted to interface to specific dependency injection
 * frameworks or for testing.
 * 
 * Implementations of this class must have a default no-arg constructor to be
 * usable by {@link InjectorBuilder}.
 * 
 * @author Erik Brakkee
 */
public interface InjectorFactory {

    /**
     * Creates an injector.
     * 
     * @return Injector fot he given class.
     * @throws IllegalArgumentException
     *             In case the given class cannot be used.
     */
    Injector create(Class aClass);

}
