/*
 * Copyright 2005-2010 the original author or authors.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/**
 * This package provides a mini-framework for interfacing to existing dependency injection 
 * mechanisms. This package does not provide dependency injection, but implementations are expected to 
 * implement it, usually by delegating to an existing dependency injection framework. The interfaces in this
 * package provide independence on the actual framework chosen and also allow for better testability. 
 * 
 * <h2>Users of the package</h2>
 * 
 * <p>Users of this package will typically use: </p>
 * <ul>
 *   <li> <code>Injector</code>: This is the interface used to perform injection of dependencies into 
 *        a given object. </li>
 *   <li> <code>Injectable</code>: By subclassing this class, the classes automatically get their 
 *        dependencies injected at construction. </li>
 *   <li> <code>InjectorBuilder</code>: To get an instance of the  <code>Injector</code>.
 *   </li>
 * </ul>
 * 
 * <p>For example, to inject into a given object, use:</p>
 * <pre>
 *   Injector injector = InjectorBuilder.getInjector();
 *   MyPojo pojo = new MyPojo();
 *   injector.inject(pojo);
 * </pre>
 * 
 * <h2>Implementors of the package</h2>
 * 
 * <p>Of interest to implementations of this package integrating with dependency injection frameworks are: </p>
 * <ul>
 *   <li> <code>Injector</code>: The main interface to be implemented is the {@link Injector}, by which injection is done.</li>
 *   <li> <code>InjectorFactory</code>: Injectors are created by an implementation of the {@link InjectorFactory} which 
 * creates injectors based on the class.</li>
 *   <li> <code>InjectorBuilder</code>: Implementations must make their <code>InjectorFactory</code>
 *       available through the <code>ServiceLoader</code> mechanism. 
 *   </li>
 * </ul>
 * 
 * <p>Class overview</p>
 * <img src="doc-files/Class_Diagram__overview.png"/>
 *
 */
package org.wamblee.inject;

